{{ hidden_input }}
<a href="{{ related_url }}{{ url }}" data-name="{{ name }}" data-app="{{ app_name }}" data-model="{{ model_name }}" class="salmonella-related-lookup" id="lookup_id_{{ name }}" >
    <img src="{{ SALMONELLA_STATIC }}img/selector-search.gif" alt="Lookup" height="16" width="16">
</a>
<a data-name="developers" data-app="{{ app_name }}" data-model="{{ model_name }}" class="salmonella-clear-field">
    <img src="{{ SALMONELLA_STATIC }}img/icon_deletelink.gif" alt="Lookup" height="10" width="10">
</a>
<span class="salmonella_label" id="{{ name }}_salmonella_label"></span>
